---
layout: ""
page_title: "Provider: oVirt"
description: |-
The oVirt provides the ability to interact with the oVirt Engine / RHV Manager API.
---

# oVirt provider

The oVirt provider interacts with the oVirt Engine / RHV Manager API. The provider can be initialized in two modes:

1. By setting the `url`, `username`, `password`, and at least one of the `tls_` options for the oVirt Engine. This will
   perform all changes on the configured oVirt Engine. (You may provide more than one `tls_` option.)
2. By setting `mock = true`. In this mode the provider will perform everything in-memory. In this mode the provider
   will drop all changes from memory once it is finished. This is mainly intended for testing and should not be used
   in production.

## Example Usage

```terraform
terraform {
  required_providers {
    ovirt = {
      source = "oVirt/ovirt"
    }
  }
}

provider "ovirt" {
  # Set this to your oVirt Engine URL, e.g. https://example.com/ovirt-engine/api/
  url = var.url
  # Set this to your oVirt username, e.g. admin@internal
  username = var.username
  # Set this to your oVirt password.
  password = var.password
  # Take trusted certificates from the specified files (list).
  tls_ca_files = var.tls_ca_files
  # Take trusted certificates from the specified directories (list).
  tls_ca_dirs = var.tls_ca_dirs
  # Take the trusted certificates from the provided variable. Certificates must be in PEM format.
  tls_ca_bundle = var.tls_ca_bundle
  # Set this to true to use the system certificate storage to verify the engine certificate. You must
  # add the certificate to your trusted roots before running. This option doesn't work on Windows.
  tls_system = var.tls_system
  # Set this to true to disable certificate verification. This is a terrible idea.
  tls_insecure = var.tls_insecure
  # Set to true if you want to run an in-memory test. In this mode all other options will be ignored.
  mock = var.mock
  # Set extra headers to add to each request.
  extra_headers = {
    "X-Custom-Header" = "Hello world!"
  }
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Optional

- `extra_headers` (Map of String) Additional HTTP headers to set on each API call.
- `mock` (Boolean) When set to true, the Terraform provider runs against an internal simulation. This should only be used for testing when an oVirt engine is not available as the mock backend does not persist state across runs. When set to false, one of the tls_ options is required.
- `password` (String, Sensitive) Password for oVirt authentication. Required when mock = false.
- `tls_ca_bundle` (String) Validate the Engine certificate against the provided CA certificates. The certificate chain passed should be in PEM format. Can be used in parallel with other `tls_` options, one `tls_` option is required when mock = false.
- `tls_ca_dirs` (List of String) Validate the engine certificate against the CA certificates provided in the specified directories. The directory should contain only files with certificates in PEM format. Can be used in parallel with other tls_ options, one tls_ option is required when mock = false.
- `tls_ca_files` (List of String) Validate the Engine certificate against the CA certificates provided in the files in this parameter. The files should contain certificates in PEM format. Can be used in parallel with other tls_ options, one tls_ option is required when mock = false.
- `tls_insecure` (Boolean) Disable certificate verification when connecting the Engine. This is not recommended. Setting this option is incompatible with other `tls_` options.
- `tls_system` (Boolean) Use the system certificate pool to verify the Engine certificate. This does not work on Windows. Can be used in parallel with other `tls_` options, one tls_ option is required when mock = false.
- `url` (String) URL for the oVirt engine API. Required when mock = false. Example: `https://example.com/ovirt-engine/api/`
- `username` (String) Username and realm for oVirt authentication. Required when mock = false. Example: `admin@internal`