---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "ovirt_disk_attachment Resource - terraform-provider-ovirt"
subcategory: ""
description: |-
  The ovirtdiskattachment resource attaches a single disk to a single VM. For controlling multiple attachments use ovirtdiskattachments.
  ~> Do not use this resource when using ovirtdiskattachments (plural) on the same VM as it will cause a ping-pong effect of resources being created and removed on each run.
---

# ovirt_disk_attachment (Resource)

The ovirt_disk_attachment resource attaches a single disk to a single VM. For controlling multiple attachments use ovirt_disk_attachments.

~> Do not use this resource when using ovirt_disk_attachments (plural) on the same VM as it will cause a ping-pong effect of resources being created and removed on each run.

## Example Usage

```terraform
data "ovirt_blank_template" "blank" {
}

resource "ovirt_disk" "test" {
  storage_domain_id = var.storage_domain_id
  format           = "raw"
  size             = 1048576
  alias            = "test"
  sparse           = true
}

resource "ovirt_vm" "test" {
  name        = random_string.vm_name.result
  comment     = "Hello world!"
  cluster_id  = var.cluster_id
  template_id = data.ovirt_blank_template.blank.id
}

resource "ovirt_disk_attachment" "test" {
  vm_id          = ovirt_vm.test.id
  disk_id        = ovirt_disk.test.id
  disk_interface = "virtio_scsi"
  bootable       = true
  active         = true
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `disk_id` (String) ID of the disk to attach. This disk must either be shared or not yet attached to a different VM.
- `disk_interface` (String) Type of interface to use for attaching disk. One of: `ide`, `sata`, `spapr_vscsi`, `virtio`, `virtio_scsi`.
- `vm_id` (String) ID of the VM the disk should be attached to.

### Optional

- `active` (Boolean) Defines whether the disk is active in the virtual machine it is attached to.
- `bootable` (Boolean) Defines whether the disk is bootable.

### Read-Only

- `id` (String) The ID of this resource.

## Import

Import is supported using the following syntax:

```shell
# Import a disk attachment using the VM ID and disk attachment ID from the oVirt Engine.
terraform import ovirt_disk_attachment.test 3b940b57-d3a5-448e-9bb3-0d73b76fbb08/7f7f43a8-7fc9-439e-96a0-2cb1737f9234
```
