---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "ovirt_vm Resource - terraform-provider-ovirt"
subcategory: ""
description: |-
  The ovirt_vm resource creates a virtual machine in oVirt.
---

# ovirt_vm (Resource)

The ovirt_vm resource creates a virtual machine in oVirt.

## Example Usage

```terraform
data "ovirt_blank_template" "blank" {
}

resource "ovirt_vm" "test" {
  name        = random_string.vm_name.result
  comment     = "Hello world!"
  cluster_id  = var.cluster_id
  template_id = data.ovirt_blank_template.blank.id
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `cluster_id` (String) Cluster to create this VM on.
- `name` (String) User-provided name for the VM. Must only consist of lower- and uppercase letters, numbers, dash, underscore and dot.
- `template_id` (String) Base template for this VM.

### Optional

- `clone` (Boolean) If true, the VM is cloned from the template instead of linked. As a result, the template can be removed and the VM still exists.
- `comment` (String) User-provided comment for the VM.
- `cpu_cores` (Number) Number of CPU cores to allocate to the VM. If set, cpu_threads and cpu_sockets must also be specified.
- `cpu_mode` (String) Sets the CPU mode for the VM. Can be one of: custom, host_model, host_passthrough
- `cpu_sockets` (Number) Number of CPU sockets to allocate to the VM. If set, cpu_cores and cpu_threads must also be specified.
- `cpu_threads` (Number) Number of CPU threads to allocate to the VM. If set, cpu_cores and cpu_sockets must also be specified.
- `huge_pages` (Number) Sets the HugePages setting for the VM. Must be one of: 2048, 1048576
- `initialization_custom_script` (String) Custom script that passed to VM during initialization.
- `initialization_hostname` (String) hostname that is set during initialization.
- `instance_type_id` (String) Defines the VM instance type ID overrides the hardware parameters of the created VM.
- `maximum_memory` (Number) Maximum memory to assign to the VM in the memory policy in bytes.
- `memory` (Number) Memory to assign to the VM in bytes.
- `memory_ballooning` (Boolean) Turn memory ballooning on or off for the VM.
- `os_type` (String) Operating system type.
- `placement_policy_affinity` (String) Affinity for placement policies. Must be one of: migratable, pinned, user_migratable
- `placement_policy_host_ids` (Set of String) List of hosts to pin the VM to.
- `serial_console` (Boolean) Enable or disable the serial console.
- `template_disk_attachment_override` (Block Set) Override parameters for disks obtained from templates. (see [below for nested schema](#nestedblock--template_disk_attachment_override))
- `vm_type` (String) Virtual machine type. Must be one of: desktop, server, high_performance

### Read-Only

- `effective_template_id` (String) Effective template ID used to create this VM. 
		This field yields the same value as "template_id" unless the "clone" field is set to true. In this case the blank template id is returned.
- `id` (String) oVirt ID of this VM.
- `status` (String) Status of the virtual machine. One of: `down`, `image_locked`, `migrating`, `not_responding`, `paused`, `powering_down`, `powering_up`, `reboot_in_progress`, `restoring_state`, `saving_state`, `suspended`, `unassigned`, `unknown`, `up`, `wait_for_launch`.

<a id="nestedblock--template_disk_attachment_override"></a>
### Nested Schema for `template_disk_attachment_override`

Required:

- `disk_id` (String) ID of the disk to be changed.

Optional:

- `format` (String) Disk format for the override. Can be 'raw' or 'cow'.
- `provisioning` (String) Provisioning the disk. Must be one of sparse,non-sparse

## Import

Import is supported using the following syntax:

```shell
# Import a VM using the ID from the oVirt Engine.
terraform import ovirt_vm.test 3b940b57-d3a5-448e-9bb3-0d73b76fbb08
```
