---
# generated by https://github.com/hashicorp/terraform-plugin-docs
page_title: "ovirt_vm_start Resource - terraform-provider-ovirt"
subcategory: ""
description: |-
  The ovirtvmstart resource starts a VM in oVirt when created and stops the VM when destroyed. If additional resources should be created before the VM is started, please use the depends_on clause.
---

# ovirt_vm_start (Resource)

The ovirt_vm_start resource starts a VM in oVirt when created and stops the VM when destroyed. If additional resources should be created before the VM is started, please use the `depends_on` clause.

## Example Usage

```terraform
data "ovirt_blank_template" "blank" {
}

resource "ovirt_disk_from_image" "test" {
  storage_domain_id = var.storage_domain_id
  format           = "raw"
  alias            = "test"
  sparse           = true
  source_file      = "./testimage/image"
}

resource "ovirt_vm" "test" {
  name        = random_string.vm_name.result
  cluster_id  = var.cluster_id
  template_id = data.ovirt_blank_template.blank.id
}

resource "ovirt_disk_attachment" "test" {
  vm_id          = ovirt_vm.test.id
  disk_id        = ovirt_disk_from_image.test.id
  disk_interface = "virtio_scsi"
}

resource "ovirt_nic" "test" {
  vnic_profile_id = var.vnic_profile_id
  vm_id           = ovirt_vm.test.id
  name            = "eth0"
}

resource "ovirt_vm_start" "test" {
  vm_id = ovirt_vm.test.id
  // How to stop the VM. Defaults to "shutdown" for an ACPI shutdown.
  stop_behavior = "stop"
  // Force-stop the VM even if a backup is currently running.
  force_stop = true

  # Wait with the start until the NIC and disks are attached.
  depends_on = [ovirt_nic.test, ovirt_disk_attachment.test]
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `vm_id` (String) oVirt ID of the VM to be started.

### Optional

- `force_stop` (Boolean) Force stop/shutdown even if a backup is in progress.
- `status` (String) Desired status of the VM. The only valid value is "up".
- `stop_behavior` (String) Use "stop" to power-off the machine, or "shutdown" (default) to send an ACPI shutdown.

### Read-Only

- `id` (String) oVirt ID of the VM to be started.

## Import

Import is supported using the following syntax:

```shell
# Import a VM using the ID from the oVirt Engine.
terraform import ovirt_vm_start.test 3b940b57-d3a5-448e-9bb3-0d73b76fbb08
```
